braindecode.visualization package
=================================

.. automodule:: braindecode.visualization
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

braindecode.visualization.input\_windows module
-----------------------------------------------

.. automodule:: braindecode.visualization.input_windows
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.visualization.perturbation module
---------------------------------------------

.. automodule:: braindecode.visualization.perturbation
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.visualization.plot module
-------------------------------------

.. automodule:: braindecode.visualization.plot
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.visualization.sensor\_positions module
--------------------------------------------------

.. automodule:: braindecode.visualization.sensor_positions
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.visualization.sinfit module
---------------------------------------

.. automodule:: braindecode.visualization.sinfit
   :members:
   :undoc-members:
   :show-inheritance:

